@@ -2,9 +2,7 @@ package CanvasRichText;
 use strict;
 use utf8;
 use Gnome2::Canvas;
-use utf8;
-use constant TRUE => 1;
-use constant FALSE => 0;
+use Glib qw(TRUE FALSE);
 
 sub setup_text {
 	my $root = shift;
